==> jaanca-0.1.4.tar.gz: jaanca-0.1.4/README.md <==
<p align="center">
    <em>jaanca public libraries</em>
</p>

<p align="center">
<a href="https://pypi.org/project/jaanca" target="_blank">
    <img src="https://img.shields.io/pypi/v/jaanca?color=blue&label=PyPI%20Package" alt="Package version">
</a>
<a href="(https://www.python.org" target="_blank">
    <img src="https://img.shields.io/badge/Python-%5B%3E%3D3.8%2C%3C%3D3.11%5D-blue" alt="Python">
</a>
</p>


---

#  A tool library created by jaanca

[Source code](https://github.com/jaanca/python-libraries/tree/main/jaanca)
| [Package (PyPI)](https://pypi.org/project/jaanca/)

---

# Here is a non-exhaustive list of related packages:

- [jaanca-chronometer](https://pypi.org/project/jaanca-chronometer/) : jaanca's helper chronometer.
- [jaanca-datetime](https://pypi.org/project/jaanca-datetime/) : jaanca's helper for date and time management and moving dates between time days by UTC.
- [jaanca-datetime](https://pypi.org/project/jaanca-utils-os/) : jaanca's helper for operating system help functions such as reading environment variables, reading/writing files, file properties, among others.

---

# Semantic Versioning

jaanca < MAJOR >.< MINOR >.< PATCH >

* **MAJOR**: version when you make incompatible API changes
* **MINOR**: version when you add functionality in a backwards compatible manner
* **PATCH**: version when you make backwards compatible bug fixes

## Definitions for releasing versions
* https://peps.python.org/pep-0440/

    - X.YaN (Alpha release): Identify and fix early-stage bugs. Not suitable for production use.
    - X.YbN (Beta release): Stabilize and refine features. Address reported bugs. Prepare for official release.
    - X.YrcN (Release candidate): Final version before official release. Assumes all major features are complete and stable. Recommended for testing in non-critical environments.
    - X.Y (Final release/Stable/Production): Completed, stable version ready for use in production. Full release for public use.
---

# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Types of changes

- Added for new features.
- Changed for changes in existing functionality.
- Deprecated for soon-to-be removed features.
- Removed for now removed features.
- Fixed for any bug fixes.
- Security in case of vulnerabilities.

## [0.0.1rcX] - 2024-05-21
### Added
- First tests using pypi.org in develop environment.
- Examples of use are added to the documentation of the functions in docstring
- In the samples folder of this library, there are complete working examples of using the code.

## [0.1.X] - 2024-05-21
### Added
- Completion of testing and launch into production.

## [0.1.2] - 2024-05-23
### Added
- Documentation improvements.

## [0.1.3] - 2024-05-24
### Added
- New feature jaanca-datetime.

## [0.1.4] - 2024-05-27
### Added
- New feature jaanca-utils-os.

==> jaanca-0.1.5.tar.gz: jaanca-0.1.5/README.md <==
<p align="center">
    <em>jaanca public libraries</em>
</p>

<p align="center">
<a href="https://pypi.org/project/jaanca" target="_blank">
    <img src="https://img.shields.io/pypi/v/jaanca?color=blue&label=PyPI%20Package" alt="Package version">
</a>
<a href="(https://www.python.org" target="_blank">
    <img src="https://img.shields.io/badge/Python-%5B%3E%3D3.8%2C%3C%3D3.11%5D-blue" alt="Python">
</a>
</p>


---

#  A tool library created by jaanca

[Source code](https://github.com/jaanca/python-libraries/tree/main/jaanca)
| [Package (PyPI)](https://pypi.org/project/jaanca/)

---

# Here is a non-exhaustive list of related packages:

- [jaanca-chronometer](https://pypi.org/project/jaanca-chronometer/) : jaanca's helper chronometer.
- [jaanca-datetime](https://pypi.org/project/jaanca-datetime/) : jaanca's helper for date and time management and moving dates between time days by UTC.
- [jaanca-utils-os](https://pypi.org/project/jaanca-utils-os/) : jaanca's helper for operating system help functions such as reading environment variables, reading/writing files, file properties, among others.

---

# Semantic Versioning

jaanca < MAJOR >.< MINOR >.< PATCH >

* **MAJOR**: version when you make incompatible API changes
* **MINOR**: version when you add functionality in a backwards compatible manner
* **PATCH**: version when you make backwards compatible bug fixes

## Definitions for releasing versions
* https://peps.python.org/pep-0440/

    - X.YaN (Alpha release): Identify and fix early-stage bugs. Not suitable for production use.
    - X.YbN (Beta release): Stabilize and refine features. Address reported bugs. Prepare for official release.
    - X.YrcN (Release candidate): Final version before official release. Assumes all major features are complete and stable. Recommended for testing in non-critical environments.
    - X.Y (Final release/Stable/Production): Completed, stable version ready for use in production. Full release for public use.
---

# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## Types of changes

- Added for new features.
- Changed for changes in existing functionality.
- Deprecated for soon-to-be removed features.
- Removed for now removed features.
- Fixed for any bug fixes.
- Security in case of vulnerabilities.

## [0.0.1rcX] - 2024-05-21
### Added
- First tests using pypi.org in develop environment.
- Examples of use are added to the documentation of the functions in docstring
- In the samples folder of this library, there are complete working examples of using the code.

## [0.1.X] - 2024-05-21
### Added
- Completion of testing and launch into production.

## [0.1.2] - 2024-05-23
### Added
- Documentation improvements.

## [0.1.3] - 2024-05-24
### Added
- New feature jaanca-datetime.

## [0.1.4-5] - 2024-05-27
### Added
- New feature jaanca-utils-os.
